@@ -2,9 +2,9 @@
 #include <scroller.h>
 
 /*
- * $Author: Corentin.Delorme $
- * $Date: 2013/09/01 17:45:00 $
- * $Revision: 1.154 $
+ * $Author: tom $
+ * $Date: 2019/02/20 14:15:43 $
+ * $Revision: 1.157 $
  */
 
 /*
@@ -227,7 +227,7 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen,
  */
 static void fixCursorPosition (CDKSELECTION *selection)
 {
-   scroller_FixCursorPosition((CDKSCROLLER *)selection);
+   scroller_FixCursorPosition ((CDKSCROLLER *)selection);
 }
 
 /*
@@ -242,10 +242,11 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
    {
       chtype input;
       boolean functionKey;
-      int ret;
 
       for (;;)
       {
+	 int ret;
+
 	 fixCursorPosition (selection);
 	 input = (chtype)getchCDKObject (ObjOf (selection), &functionKey);
 
@@ -261,12 +262,11 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
    {
       int length = chlen (actions);
       int j = 0;
-      int ret;
 
       /* Inject each character one at a time. */
       for (j = 0; j < length; j++)
       {
-	 ret = injectCDKSelection (selection, actions[j]);
+	 int ret = injectCDKSelection (selection, actions[j]);
 	 if (selection->exitType != vEARLY_EXIT)
 	 {
 	    return ret;
@@ -516,8 +516,7 @@ static void drawCDKSelectionList (CDKSELECTION *selection, boolean Box GCC_UNUSE
    /* *INDENT-EQLS* */
    int scrollbarAdj     = (selection->scrollbarPlacement == LEFT) ? 1 : 0;
    int screenPos        = 0;
-   int xpos, ypos;
-   int j, k;
+   int j;
    int selItem          = -1;
 
    /* If there is to be a highlight, assign it now */
@@ -527,8 +526,9 @@ static void drawCDKSelectionList (CDKSELECTION *selection, boolean Box GCC_UNUSE
    /* draw the list... */
    for (j = 0; j < selection->viewSize; j++)
    {
-      xpos = SCREEN_XPOS (selection, 0);
-      ypos = SCREEN_YPOS (selection, j);
+      int xpos = SCREEN_XPOS (selection, 0);
+      int ypos = SCREEN_YPOS (selection, j);
+      int k;
 
       /* Draw the empty line. */
       writeBlanks (selection->win, xpos, ypos,
@@ -674,7 +674,7 @@ void setCDKSelection (CDKSELECTION *selection,
  */
 void setCDKSelectionItems (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 {
-   int widestItem = -1;
+   int widestItem;
    int j = 0;
 
    widestItem = createList (selection, list, listSize);
@@ -697,10 +697,10 @@ void setCDKSelectionItems (CDKSELECTION *selection, CDK_CSTRING2 list, int listS
 }
 int getCDKSelectionItems (CDKSELECTION *selection, char **list)
 {
-   int j;
-
    if (list != 0)
    {
+      int j;
+
       for (j = 0; j < selection->listSize; j++)
       {
 	 list[j] = chtype2Char (selection->item[j]);
@@ -932,7 +932,16 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 {
    int status = 0;
    int widestItem = 0;
-   int j;
+
+   if (selection->listSize > 0)
+   {
+      CDKfreeChtypes (selection->item);
+      selection->item = 0;
+      freeAndNull (selection->itemLen);
+      freeAndNull (selection->itemPos);
+      freeAndNull (selection->selections);
+      freeAndNull (selection->mode);
+   }
 
    if (listSize >= 0)
    {
@@ -951,6 +960,7 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
       {
 	 int boxWidth = AvailableWidth (selection);
 	 int adjust = selection->maxchoicelen + BorderOf (selection);
+	 int j;
 
 	 status = 1;
 	 for (j = 0; j < listSize; j++)
@@ -970,11 +980,12 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 	    destroyInfo (selection);
 
 	    /* *INDENT-EQLS* */
-	    selection->item      = newList;
-	    selection->itemPos   = newPos;
-	    selection->itemLen   = newLen;
+	    selection->listSize   = listSize;
+	    selection->item       = newList;
+	    selection->itemPos    = newPos;
+	    selection->itemLen    = newLen;
 	    selection->selections = newSel;
-	    selection->mode      = newMode;
+	    selection->mode       = newMode;
 	 }
 	 else
 	 {
@@ -985,6 +996,14 @@ static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 	    freeChecked (newMode);
 	 }
       }
+      else
+      {
+	 CDKfreeChtypes (newList);
+	 freeChecked (newPos);
+	 freeChecked (newLen);
+	 freeChecked (newSel);
+	 freeChecked (newMode);
+      }
    }
    else
    {
